==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator.md <==
# AmazonBraketSimulator


```text
aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator
```

```text
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')
```



| Illustration | AmazonBraketSimulator | AmazonBraketSimulatorCard | AmazonBraketSimulatorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator.png) | ![illustration for AmazonBraketSimulator](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator.Local.png) | ![illustration for AmazonBraketSimulatorCard](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulatorCard.Local.png) | ![illustration for AmazonBraketSimulatorGroup](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulatorGroup.Local.png) |




## AmazonBraketSimulator

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')

' renders the element
AmazonBraketSimulator('AmazonBraketSimulator', 'Amazon Braket Simulator', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')

' renders the element
AmazonBraketSimulator('AmazonBraketSimulator', 'Amazon Braket Simulator', 'an optional tech label')
@enduml
```

## AmazonBraketSimulatorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulatorCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')

' renders the element
AmazonBraketSimulatorCard('AmazonBraketSimulatorCard', 'Amazon Braket Simulator Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulatorCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')

' renders the element
AmazonBraketSimulatorCard('AmazonBraketSimulatorCard', 'Amazon Braket Simulator Card', 'an optional description')
@enduml
```

## AmazonBraketSimulatorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulatorGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')

' renders the element
AmazonBraketSimulatorGroup('AmazonBraketSimulatorGroup', 'Amazon Braket Simulator Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulatorGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')

' renders the element
AmazonBraketSimulatorGroup('AmazonBraketSimulatorGroup', 'Amazon Braket Simulator Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator.md <==
# AmazonBraketSimulator


```text
aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator
```

```text
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')
```



| Illustration | AmazonBraketSimulator | AmazonBraketSimulatorCard | AmazonBraketSimulatorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator.png) | ![illustration for AmazonBraketSimulator](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator.Local.png) | ![illustration for AmazonBraketSimulatorCard](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulatorCard.Local.png) | ![illustration for AmazonBraketSimulatorGroup](../../../aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulatorGroup.Local.png) |




## AmazonBraketSimulator

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')

' renders the element
AmazonBraketSimulator('AmazonBraketSimulator', 'Amazon Braket Simulator', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulator
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')

' renders the element
AmazonBraketSimulator('AmazonBraketSimulator', 'Amazon Braket Simulator', 'an optional tech label')
@enduml
```

## AmazonBraketSimulatorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulatorCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')

' renders the element
AmazonBraketSimulatorCard('AmazonBraketSimulatorCard', 'Amazon Braket Simulator Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulatorCard
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')

' renders the element
AmazonBraketSimulatorCard('AmazonBraketSimulatorCard', 'Amazon Braket Simulator Card', 'an optional description')
@enduml
```

## AmazonBraketSimulatorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulatorGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')

' renders the element
AmazonBraketSimulatorGroup('AmazonBraketSimulatorGroup', 'Amazon Braket Simulator Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonBraketSimulatorGroup
include('aws-20210730/Resource/QuantumTechnologies/AmazonBraketSimulator')

' renders the element
AmazonBraketSimulatorGroup('AmazonBraketSimulatorGroup', 'Amazon Braket Simulator Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
